﻿;;; tr-org-html.el - Do XSLT post processing to org-mode's HTML export
;;;
;;; This software is Open Source. Use it under the GNU Public License
;;; conditions. Please do read file COPYING.TXT.
;;;
;;; Author: Dr. Thomas Redelberger, redetho@gmx.de
;;; Copyright (C) 2023  Dr. Thomas Redelberger
;;;


(require 'ox-html)



(defun tr-org-html-export-to-html (&optional async subtreep visible-only body-only ext-plist)
  "Export current buffer to an HTML file.

Export as `org-html-export-as-html' with XSLT post-processing

If narrowing is active in the current buffer, only export its
narrowed part.

If a region is active, export that region.

A non-nil optional argument ASYNC means the process should happen
asynchronously.  The resulting file should be accessible through
the `org-export-stack' interface.

When optional argument SUBTREEP is non-nil, export the sub-tree
at point, extracting information from the headline properties
first.

When optional argument VISIBLE-ONLY is non-nil, don't export
contents of hidden elements.

When optional argument BODY-ONLY is non-nil, only write code
between \"<body>\" and \"</body>\" tags.

EXT-PLIST, when provided, is a property list with external
parameters overriding Org default settings, but still inferior to
file-local settings.

/Should/ return output file's name."

  (interactive)

  ;; Get temp file names.
  ;; The second one works around xsltproc's issue with blanks in file names
  (let ((myFullTmpNameI (expand-file-name (make-temp-name "tr") temporary-file-directory)))
	(let ((myFullTmpNameO (expand-file-name (make-temp-name "tr") temporary-file-directory)))

	  ;; do the standard org to html conversion
	  (let ((myFullTgtName (concat(file-name-directory (buffer-file-name)) (org-html-export-to-html)) ))

		(rename-file myFullTgtName myFullTmpNameI)

		;; do a XSLT transformation synchronously i.e. wait for it to finish
		(with-temp-buffer  ; new buffer, which becomes the current buffer
		  (if (zerop       ; equivalent to (= x 0)
			   (call-process "xsltproc" nil t nil   ; "t" writes stdout & stderr to the current buffer
					  "--novalid" "--nonet" "--nodtdattr"
					  "-o" myFullTmpNameO
					  ;; the style sheet file must be in the same dir. as /this/ file
					  (concat (file-name-directory (symbol-file 'tr-org-html-export-to-html)) "tr-org-html-trnsfrm.xsl")
					  myFullTmpNameI))

			  (rename-file  myFullTmpNameO myFullTgtName) ; "then" part. If it is more than one statement, use progn
			(message "Error: xsltproc")     ; "else" part starts here
			(message "%s" (buffer-string))))
		)
	  )
	)
  )


(provide 'tr-org-html)
;;; tr-org-html.el ends here
